This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  1a0b06dd6dc08b5253ea12e9f1b55dee1ac803be (commit)
       via  5d5067ae57c9d02656a54076cdf121c7084a4de3 (commit)
      from  8c9e5f5e73a474ab208694007e0bee63cb801304 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1a0b06dd6dc08b5253ea12e9f1b55dee1ac803be
commit 1a0b06dd6dc08b5253ea12e9f1b55dee1ac803be
Merge: 8c9e5f5 5d5067a
Author:     Brad King <brad.k...@kitware.com>
AuthorDate: Tue Feb 24 09:45:57 2015 -0500
Commit:     CMake Topic Stage <kwro...@kitware.com>
CommitDate: Tue Feb 24 09:45:57 2015 -0500

    Merge topic 'CheckCompilerFlag-use-FLAGS' into next
    
    5d5067ae Check*CompilerFlag: Refactor method used to pass flags


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5d5067ae57c9d02656a54076cdf121c7084a4de3
commit 5d5067ae57c9d02656a54076cdf121c7084a4de3
Author:     Mark Abraham <mark.j.abra...@gmail.com>
AuthorDate: Tue Feb 24 14:20:16 2015 +0100
Commit:     Brad King <brad.k...@kitware.com>
CommitDate: Tue Feb 24 09:45:19 2015 -0500

    Check*CompilerFlag: Refactor method used to pass flags
    
    Refactor the Check*CompilerFlag modules to pass the flags to
    Check*SourceCompiles using CMAKE_REQUIRED_FLAGS instead of
    CMAKE_REQUIRED_DEFINITIONS.  Both end up being used, but the variable
    for "FLAGS" is more precise.

diff --git a/Modules/CheckCCompilerFlag.cmake b/Modules/CheckCCompilerFlag.cmake
index 53f3454..750e4fb 100644
--- a/Modules/CheckCCompilerFlag.cmake
+++ b/Modules/CheckCCompilerFlag.cmake
@@ -13,7 +13,7 @@
 #            Will be created as an internal cache variable.
 #
 # This internally calls the check_c_source_compiles macro and sets
 # CMAKE_REQUIRED_DEFINITIONS to <flag>.  See help for
 # CheckCSourceCompiles for a listing of variables that can otherwise
 # modify the build.  The result only tells that the compiler does not
 # give an error message when it encounters the flag.  If the flag has
@@ -38,8 +38,8 @@ include(CheckCSourceCompiles)
 include(CMakeCheckCompilerFlagCommonPatterns)
 
 macro (CHECK_C_COMPILER_FLAG _FLAG _RESULT)
-   set(SAFE_CMAKE_REQUIRED_DEFINITIONS "${CMAKE_REQUIRED_DEFINITIONS}")
-   set(CMAKE_REQUIRED_DEFINITIONS "${_FLAG}")
+   set(SAFE_CMAKE_REQUIRED_FLAGS "${CMAKE_REQUIRED_FLAGS}")
+   set(CMAKE_REQUIRED_FLAGS "${_FLAG}")
 
    # Normalize locale during test compilation.
    set(_CheckCCompilerFlag_LOCALE_VARS LC_ALL LC_MESSAGES LANG)
@@ -60,5 +60,5 @@ macro (CHECK_C_COMPILER_FLAG _FLAG _RESULT)
    unset(_CheckCCompilerFlag_LOCALE_VARS)
    unset(_CheckCCompilerFlag_COMMON_PATTERNS)
 
-   set (CMAKE_REQUIRED_DEFINITIONS "${SAFE_CMAKE_REQUIRED_DEFINITIONS}")
+   set (CMAKE_REQUIRED_FLAGS "${SAFE_CMAKE_REQUIRED_FLAGS}")
 endmacro ()
@@ -13,7 +13,7 @@
 #
 # This internally calls the check_c_source_compiles macro and sets
-# CMAKE_REQUIRED_DEFINITIONS to <flag>.  See help for
+# CMAKE_REQUIRED_FLAGS to <flag>.  See help for
 # CheckCSourceCompiles for a listing of variables that can otherwise
 # modify the build.  The result only tells that the compiler does not
diff --git a/Modules/CheckCXXCompilerFlag.cmake 
b/Modules/CheckCXXCompilerFlag.cmake
index fab3a05..71b3fd2 100644
--- a/Modules/CheckCXXCompilerFlag.cmake
+++ b/Modules/CheckCXXCompilerFlag.cmake
@@ -12,7 +12,7 @@
 #   <var>  - variable to store the result
 #
 # This internally calls the check_cxx_source_compiles macro and sets
 # CMAKE_REQUIRED_DEFINITIONS to <flag>.  See help for
 # CheckCXXSourceCompiles for a listing of variables that can otherwise
 # modify the build.  The result only tells that the compiler does not
 # give an error message when it encounters the flag.  If the flag has
@@ -37,8 +37,8 @@ include(CheckCXXSourceCompiles)
 include(CMakeCheckCompilerFlagCommonPatterns)
 
 macro (CHECK_CXX_COMPILER_FLAG _FLAG _RESULT)
-   set(SAFE_CMAKE_REQUIRED_DEFINITIONS "${CMAKE_REQUIRED_DEFINITIONS}")
-   set(CMAKE_REQUIRED_DEFINITIONS "${_FLAG}")
+   set(SAFE_CMAKE_REQUIRED_FLAGS "${CMAKE_REQUIRED_FLAGS}")
+   set(CMAKE_REQUIRED_FLAGS "${_FLAG}")
 
    # Normalize locale during test compilation.
    set(_CheckCXXCompilerFlag_LOCALE_VARS LC_ALL LC_MESSAGES LANG)
@@ -59,6 +59,6 @@ macro (CHECK_CXX_COMPILER_FLAG _FLAG _RESULT)
    unset(_CheckCXXCompilerFlag_LOCALE_VARS)
    unset(_CheckCXXCompilerFlag_COMMON_PATTERNS)
 
-   set (CMAKE_REQUIRED_DEFINITIONS "${SAFE_CMAKE_REQUIRED_DEFINITIONS}")
+   set (CMAKE_REQUIRED_FLAGS "${SAFE_CMAKE_REQUIRED_FLAGS}")
 endmacro ()
 
@@ -12,7 +12,7 @@
 #
 # This internally calls the check_cxx_source_compiles macro and sets
-# CMAKE_REQUIRED_DEFINITIONS to <flag>.  See help for
+# CMAKE_REQUIRED_FLAGS to <flag>.  See help for
 # CheckCXXSourceCompiles for a listing of variables that can otherwise
 # modify the build.  The result only tells that the compiler does not
diff --git a/Modules/CheckFortranCompilerFlag.cmake 
b/Modules/CheckFortranCompilerFlag.cmake
index 53fd8d6..c476661 100644
--- a/Modules/CheckFortranCompilerFlag.cmake
+++ b/Modules/CheckFortranCompilerFlag.cmake
@@ -13,7 +13,7 @@
 #            Will be created as an internal cache variable.
 #
 # This internally calls the check_fortran_source_compiles macro and
 # sets CMAKE_REQUIRED_DEFINITIONS to <flag>.  See help for
 # CheckFortranSourceCompiles for a listing of variables that can
 # otherwise modify the build.  The result only tells that the compiler
 # does not give an error message when it encounters the flag.  If the
@@ -40,8 +40,8 @@ include(CheckFortranSourceCompiles)
 include(CMakeCheckCompilerFlagCommonPatterns)
 
 macro (CHECK_Fortran_COMPILER_FLAG _FLAG _RESULT)
-  set(SAFE_CMAKE_REQUIRED_DEFINITIONS "${CMAKE_REQUIRED_DEFINITIONS}")
-  set(CMAKE_REQUIRED_DEFINITIONS "${_FLAG}")
+  set(SAFE_CMAKE_REQUIRED_FLAGS "${CMAKE_REQUIRED_FLAGS}")
+  set(CMAKE_REQUIRED_FLAGS "${_FLAG}")
 
   # Normalize locale during test compilation.
   set(_CheckFortranCompilerFlag_LOCALE_VARS LC_ALL LC_MESSAGES LANG)
@@ -62,5 +62,5 @@ macro (CHECK_Fortran_COMPILER_FLAG _FLAG _RESULT)
   unset(_CheckFortranCompilerFlag_LOCALE_VARS)
   unset(_CheckFortranCompilerFlag_COMMON_PATTERNS)
 
-  set (CMAKE_REQUIRED_DEFINITIONS "${SAFE_CMAKE_REQUIRED_DEFINITIONS}")
+  set (CMAKE_REQUIRED_FLAGS "${SAFE_CMAKE_REQUIRED_FLAGS}")
 endmacro ()

-----------------------------------------------------------------------

Summary of changes:
 Modules/CheckCCompilerFlag.cmake       |    8 ++++----
@@ -13,7 +13,7 @@
 #
 # This internally calls the check_fortran_source_compiles macro and
-# sets CMAKE_REQUIRED_DEFINITIONS to <flag>.  See help for
+# sets CMAKE_REQUIRED_FLAGS to <flag>.  See help for
 # CheckFortranSourceCompiles for a listing of variables that can
 # otherwise modify the build.  The result only tells that the compiler
 Modules/CheckCXXCompilerFlag.cmake     |    8 ++++----
 Modules/CheckFortranCompilerFlag.cmake |    8 ++++----
 3 files changed, 12 insertions(+), 12 deletions(-)


hooks/post-receive
-- 
CMake
_______________________________________________
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits

Reply via email to